==> gtkatlantic_0.2.5.tar.bz2: gtkatlantic_0.2.5/src/game.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

gboolean create_home_directory();
void read_config_files();
gboolean connect_get_valid_id(guint16 *idconnect);
void create_connection_metaserver(guint32 gametype);
void create_connection_get_games(guchar *host, guint32 port);
void text_insert_message(gchar* text, guint32 lenght);
void text_insert_chat(gchar* text, guint32 lenght);
void game_alloc();
void game_free();
gboolean game_get_valid_player_slot(guint8 *playerslot);
gint8 get_player_slot_with_playerid(guint32 playerid);
gint8 get_playerlistcard_id_with_estate(guint32 estate);
gboolean game_get_valid_command_slot(guint8 *commandslot);
gint8 get_command_button_slot_with_command(guchar *command);
void parse_chat_specific_message(guchar *message);
void game_sort_playerlist_by_playerid();
void game_write_cookie(guchar *cookie);
gboolean game_get_valid_card_slot(guint8 *cardslot);
gint8 get_card_slot_with_cardid(guint32 cardid);
gint32 get_playerid_by_playername(guchar *name);
gboolean game_get_valid_trade_slot(guint32 *tradeslot);
gint32 get_trade_slot_with_tradeid(guint32 tradeid);
gint32 get_estateid_by_estatename(guchar *name);
void game_buildplayerlist();

==> gtkatlantic_0.2.6.tar.bz2: gtkatlantic_0.2.6/src/game.h <==
/*
 *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
 *
 *
 *  Copyright (C) 2002-2003 Rochet Sylvain
 *
 *  gtkatlantic is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

gboolean create_home_directory();
void read_config_files();
gboolean connect_get_valid_id(guint16 *idconnect);
void create_connection_metaserver(guint32 gametype);
void create_connection_get_games(guchar *host, guint32 port);
void text_insert_message(gchar* text, guint32 lenght);
void text_insert_chat(gchar* text, guint32 lenght);
void game_alloc();
void game_free();
gboolean game_get_valid_player_slot(guint8 *playerslot);
gint8 get_player_slot_with_playerid(guint32 playerid);
gint8 get_playerlistcard_id_with_estate(guint32 estate);
gboolean game_get_valid_command_slot(guint8 *commandslot);
gint8 get_command_button_slot_with_command(guchar *command);
void parse_specific_chat_message(guchar *message);
void parse_specific_send_message(guchar *message);
void game_sort_playerlist_by_playerid();
void game_write_cookie(guchar *cookie);
gboolean game_get_valid_card_slot(guint8 *cardslot);
gint8 get_card_slot_with_cardid(guint32 cardid);
gint32 get_playerid_by_playername(guchar *name);
gboolean game_get_valid_trade_slot(guint32 *tradeslot);
gint32 get_trade_slot_with_tradeid(guint32 tradeid);
gint32 get_estateid_by_estatename(guchar *name);
void game_buildplayerlist();
gint32 game_get_assets_player(guint32 playerid);
void game_update_tokens();
void game_start_move_token(guint32 playerid);
gboolean game_move_tokens();
